FOM_sub_calculations: FOM_sub_calculations

View source: R/FOM.R

FOM_sub_calculationsR Documentation

FOM_sub_calculations

Description

Calculate FOM decomposition and carbon fluxes in the subsoil layer.

Usage

FOM_sub_calculations(FOM_sub_t, month, t_avg, amplitude, s_config)

Arguments

FOM_sub_t

Numeric. Carbon content in FOM subsoil pool (Mg C ha-1).

month

Integer. Month index (1–12).

t_avg

Numeric. Monthly mean air temperature (°C).

amplitude

Numeric. Annual historical temperature amplitude used in the soil temperature function.

s_config

List. Soil configuration parameters

Value

A list with updated pool values and fluxes for FOM subsoil layer.

Examples

FOM_sub_calculations(
  FOM_sub_t = 10,
  month = 7,
  t_avg = 15,
  amplitude = 10,
  s_config = soil_config()
)

rCTOOL documentation built on July 4, 2026, 9:07 a.m.