| FOM_top_calculations | R Documentation |
Calculate FOM decomposition and carbon fluxes in the topsoil layer.
FOM_top_calculations(
FOM_top_t,
month,
t_avg = t_avg,
amplitude = amplitude,
s_config
)
FOM_top_t |
Numeric. Carbon content in FOM top pool (Mg C ha-1). |
month |
Integer. Month index (1–12). |
t_avg |
Numeric. Monthly mean air temperature (°C). |
amplitude |
Numeric. Annual historical temperature amplitude used in the soil temperature function. |
s_config |
List. Soil configuration parameters. |
A list with updated pool values and fluxes for FOM topsoil layer.
FOM_top_calculations(
FOM_top_t = 10,
month = 7,
t_avg = 15,
amplitude = 10,
s_config = soil_config()
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.