| HUM_top_calculations | R Documentation |
Calculate HUM decomposition and carbon fluxes in the topsoil layer.
HUM_top_calculations(
HUM_top_t,
month,
t_avg = t_avg,
amplitude = amplitude,
s_config
)
HUM_top_t |
Numeric. Carbon content in the HUM topsoil pool (Mg C ha-1). |
month |
Integer. Month index (1-12). |
t_avg |
Numeric. Monthly mean air temperature (degrees C). |
amplitude |
Numeric. Annual historical temperature amplitude used in the soil temperature function. |
s_config |
List. Soil configuration parameters. |
A list with updated HUM topsoil pool values and associated fluxes.
HUM_top_calculations(
HUM_top_t = 20,
month = 7,
t_avg = 15,
amplitude = 10,
s_config = soil_config()
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.