View source: R/Physical_boundaries.R
| check_balance | R Documentation |
Check carbon balance consistency of a simulation.
check_balance(ctool_output, cin_config, s_config)
ctool_output |
Output from turnover model. |
cin_config |
Carbon input configuration. |
s_config |
Soil configuration. |
Computes the balance between initial soil carbon, cumulative carbon inputs, final carbon stocks and cumulative CO2 emissions. The balance should be zero or very close to zero.
The input 'ctool_output' data.frame, returned unchanged after checking carbon balance consistency.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.