define_Cinputs: define_Cinputs

View source: R/Parameter_config.R

define_CinputsR Documentation

define_Cinputs

Description

Prepare annual carbon input (from plants and/or manure) configuration.

Usage

define_Cinputs(
  management_filepath = NULL,
  Cin_top = NULL,
  Cin_sub = NULL,
  Cin_man = NULL,
  time_config = NULL
)

Arguments

management_filepath

Either a filepath to a management template or a data.frame containing 'Cin_top', 'Cin_sub' and 'Cin_man'.

Cin_top

Annual carbon input from plant residues in the topsoil.

Cin_sub

Annual carbon input from plant residues in the subsoil.

Cin_man

Annual carbon input from manure.

time_config

Time configuration object returned by 'define_timeperiod()'

Value

A list containing 'Cin_top', 'Cin_sub' and 'Cin_man'.

Examples

time_config <- define_timeperiod(yr_start = 2006, yr_end = 2008)
define_Cinputs(
  Cin_top = c(2, 2, 2),
  Cin_sub = c(0.5, 0.5, 0.5),
  Cin_man = c(1, 1, 1),
  time_config = time_config
)

rCTOOL documentation built on July 4, 2026, 9:07 a.m.