View source: R/Physical_boundaries.R
| define_physical_boundaries | R Documentation |
Check whether a parameter value lies within specified physical bounds.
define_physical_boundaries(value, min_limit, max_limit)
value |
parameter value |
min_limit |
Minimum allowed value. |
max_limit |
Maximum allowed value. |
The input value if it lies within the specified physical bounds.
define_physical_boundaries(0.3, 0, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.