set_monthly_temperature_data: set_monthly_temperature_data

View source: R/Temperature.R

set_monthly_temperature_dataR Documentation

set_monthly_temperature_data

Description

Prepare monthly temperature input data for rCTOOL.

Usage

set_monthly_temperature_data(file = NULL, Tavg = NULL)

Arguments

file

Either a filepath to a csv file or a data.frame containing monthly temperature data.

Tavg

Numeric vector of average monthly temperature values.

Details

Monthly temperature data can be provided in two ways: 1. directly through the argument 'file', as a filepath or data.frame containing monthly temperature data 2. directly through the argument 'Tavg', as a numeric vector of average monthly temperature values

Value

A data.frame containing monthly temperature input data. The output always contains 'Tavg'.

Examples

df_temp <- data.frame(Tavg = c(5, 6, 7, 8, 9, 15, 14, 11, 10, 9, 5, 1))
set_monthly_temperature_data(file = df_temp)

set_monthly_temperature_data(
  Tavg = c(5, 6, 7, 8, 9, 15, 14, 11, 10, 9, 5, 1)
)

rCTOOL documentation built on July 4, 2026, 9:07 a.m.