set_monthly_temperature_data_historical_amplitude: set_monthly_temperature_data_historical_amplitude

View source: R/Temperature.R

set_monthly_temperature_data_historical_amplitudeR Documentation

set_monthly_temperature_data_historical_amplitude

Description

Prepare monthly temperature input with a single historical amplitude.

Usage

set_monthly_temperature_data_historical_amplitude(file = NULL, Tavg = NULL)

Arguments

file

Either a filepath to a csv file or a data.frame containing monthly temperature data.

Tavg

Numeric vector of average monthly temperature values.

Details

Monthly 'Tavg' data can be provided either as a filepath/data.frame through 'file' or directly as a numeric vector through 'Tavg'.

A single historical amplitude is calculated from the full monthly 'Tavg' series as:

(max(Tavg) - min(Tavg)) / 2

This historical amplitude is then assigned to the full series in the 'Amplitude' column.

Value

A data.frame containing 'Tavg' and a single historical 'Amplitude' repeated over the full series.

Examples

set_monthly_temperature_data_historical_amplitude(
  Tavg = c(1, 2, 4, 7, 11, 15, 17, 16, 13, 9, 5, 2)
)

rCTOOL documentation built on July 4, 2026, 9:07 a.m.