update_monthly_ROM_sub: update_monthly_ROM_sub

View source: R/Update_soil_pools.R

update_monthly_ROM_subR Documentation

update_monthly_ROM_sub

Description

update_monthly_ROM_sub

Usage

update_monthly_ROM_sub(ROM_sub_t1, HUM_romified_sub, ROM_transport)

Arguments

ROM_sub_t1

ROM content in the subsoil layer from the previous timestep.

HUM_romified_sub

Romified HUM added to the subsoil ROM pool.

ROM_transport

ROM transported from the topsoil.

Value

Updated ROM content in the subsoil layer after romified HUM additions and transport from the topsoil.


rCTOOL documentation built on July 4, 2026, 9:07 a.m.