update_monthly_ROM_top: update_monthly_ROM_top

View source: R/Update_soil_pools.R

update_monthly_ROM_topR Documentation

update_monthly_ROM_top

Description

update_monthly_ROM_top

Usage

update_monthly_ROM_top(ROM_top_t1, HUM_romified_top)

Arguments

ROM_top_t1

ROM content in the topsoil layer from the previous timestep.

HUM_romified_top

Romified HUM added to the topsoil ROM pool.

Value

Updated ROM content in the topsoil layer after romified HUM additions.


rCTOOL documentation built on July 4, 2026, 9:07 a.m.