| ROM_top_calculations | R Documentation |
Calculate ROM decomposition and carbon fluxes in the topsoil layer.
ROM_top_calculations(ROM_top_t, month, t_avg, amplitude, s_config)
ROM_top_t |
Numeric. Carbon content in the ROM topsoil pool (Mg C ha-1). |
month |
Integer. Month index (1-12). |
t_avg |
Numeric. Monthly mean air temperature (degrees C). |
amplitude |
Numeric. Annual historical temperature amplitude used in the soil temperature function. |
s_config |
List. Soil configuration parameters. |
A list with updated ROM topsoil pool values and associated fluxes.
ROM_top_calculations(
ROM_top_t = 10,
month = 7,
t_avg = 15,
amplitude = 10,
s_config = soil_config()
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.