| .clean_monthly_allocations | R Documentation |
Clean and harmonize monthly allocation inputs.
.clean_monthly_allocations(m_config)
m_config |
Management configuration list. |
Reads management configuration with monthly allocation vectors and returns a configuration containing 'plant_monthly_allocation'.
Depending on the user input: - if plant, grain and grass allocations are all provided, plant allocation is recalculated as grain plus grass - if only one allocation is provided, it is treated as plant allocation - if two allocations are provided, they must correspond to grain and grass; otherwise an error is returned
A management configuration list containing 'plant_monthly_allocation'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.