| .soil_temp | R Documentation |
.soil_temp
.soil_temp(depth, month, T_ave, Amplitude, th_diff)
depth |
Soil layer reference depth in cm. In the default C-TOOL configuration, the model operates with two fixed layers: topsoil (25 cm) and subsoil (100 cm). |
month |
Month index (1 to 12). |
T_ave |
Monthly mean air temperature. |
Amplitude |
Annual temperature amplitude used in the soil temperature equation. |
th_diff |
Thermal diffusivity. |
Soil temperature at the midpoint of the soil layer for the specified monthly timestep.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.