| set_monthly_temperature_data | R Documentation |
Prepare monthly temperature input data for rCTOOL.
set_monthly_temperature_data(file = NULL, Tavg = NULL)
file |
Either a filepath to a csv file or a data.frame containing monthly temperature data. |
Tavg |
Numeric vector of average monthly temperature values. |
Monthly temperature data can be provided in two ways: 1. directly through the argument 'file', as a filepath or data.frame containing monthly temperature data 2. directly through the argument 'Tavg', as a numeric vector of average monthly temperature values
A data.frame containing monthly temperature input data. The output always contains 'Tavg'.
df_temp <- data.frame(Tavg = c(5, 6, 7, 8, 9, 15, 14, 11, 10, 9, 5, 1))
set_monthly_temperature_data(file = df_temp)
set_monthly_temperature_data(
Tavg = c(5, 6, 7, 8, 9, 15, 14, 11, 10, 9, 5, 1)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.