View source: R/Update_soil_pools.R
| update_monthly_FOM_sub | R Documentation |
update_monthly_FOM_sub
update_monthly_FOM_sub(
FOM_sub_t1,
FOM_transport,
C_in_plant_sub,
month,
m_config
)
FOM_sub_t1 |
FOM content in the subsoil layer from the previous timestep. |
FOM_transport |
FOM transported from the topsoil. |
C_in_plant_sub |
Plant carbon input to the subsoil. |
month |
Month index from 1 to 12. |
m_config |
Management configuration list. |
Updated FOM content in the subsoil layer after plant inputs and transport from the topsoil.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.