View source: R/Update_soil_pools.R
| update_monthly_HUM_sub | R Documentation |
update_monthly_HUM_sub
update_monthly_HUM_sub(HUM_sub_t1, HUM_transport, FOM_humified_sub)
HUM_sub_t1 |
HUM content in the subsoil layer from the previous timestep. |
HUM_transport |
HUM transported from the topsoil. |
FOM_humified_sub |
Humified FOM added to the subsoil HUM pool. |
Updated HUM content in the subsoil layer after transport and humified FOM additions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.