View source: R/Update_soil_pools.R
| update_monthly_ROM_sub | R Documentation |
update_monthly_ROM_sub
update_monthly_ROM_sub(ROM_sub_t1, HUM_romified_sub, ROM_transport)
ROM_sub_t1 |
ROM content in the subsoil layer from the previous timestep. |
HUM_romified_sub |
Romified HUM added to the subsoil ROM pool. |
ROM_transport |
ROM transported from the topsoil. |
Updated ROM content in the subsoil layer after romified HUM additions and transport from the topsoil.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.