View source: R/Update_soil_pools.R
| update_monthly_ROM_top | R Documentation |
update_monthly_ROM_top
update_monthly_ROM_top(ROM_top_t1, HUM_romified_top)
ROM_top_t1 |
ROM content in the topsoil layer from the previous timestep. |
HUM_romified_top |
Romified HUM added to the topsoil ROM pool. |
Updated ROM content in the topsoil layer after romified HUM additions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.